==> p2-maven-plugin-1.2.0-sources.jar: org/reficio/p2/resolver/maven/impl/facade/AetherSonatypeFacade.java <==
package org.reficio.p2.resolver.maven.impl.facade;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class AetherSonatypeFacade
  extends java.lang.Object  implements
    org.reficio.p2.resolver.maven.impl.facade.AetherFacade,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  java.lang.Object newDependencyRequest(java.lang.Object dependencyNode, java.lang.Object dependencyFilter) { return null;}
@java.lang.Override() public  java.lang.Object newPreorderNodeListGenerator() { return null;}
@java.lang.Override() public  java.lang.Object newCollectRequest() { return null;}
@java.lang.Override() public  java.lang.Object newDependency(java.lang.Object defaultArtifact, java.lang.String scope) { return null;}
@java.lang.Override() public  java.lang.Object newDefaultArtifact(java.lang.Object artifact) { return null;}
@java.lang.Override() public  java.lang.Object newArtifactRequest() { return null;}
@java.lang.Override() public  java.lang.Object newSubArtifact(java.lang.Object artifact, java.lang.String classifier, java.lang.String extension) { return null;}
@java.lang.Override() public  java.lang.Object newPatternExclusionsDependencyFilter(java.util.List<java.lang.String> excludes) { return null;}
@java.lang.Override() public  java.lang.Object newDependencyFilter(java.lang.Object filterClosure) { return null;}
@java.lang.Override() public  org.reficio.p2.resolver.maven.Artifact translateArtifactAetherToGeneric(java.lang.Object artifact) { return (org.reficio.p2.resolver.maven.Artifact)null;}
@java.lang.Override() public  java.lang.Object translateArtifactGenericToAether(org.reficio.p2.resolver.maven.Artifact a) { return null;}
}

==> p2-maven-plugin-1.7.0-sources.jar: org/reficio/p2/resolver/maven/impl/facade/AetherSonatypeFacade.java <==
package org.reficio.p2.resolver.maven.impl.facade;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

@edu.umd.cs.findbugs.annotations.SuppressFBWarnings(value="SE_NO_SERIALVERSIONID") public class AetherSonatypeFacade
  extends java.lang.Object  implements
    org.reficio.p2.resolver.maven.impl.facade.AetherFacade,    groovy.lang.GroovyObject {
;
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@java.lang.Override() public  java.lang.Object newDependencyRequest(java.lang.Object dependencyNode, java.lang.Object dependencyFilter) { return null;}
@java.lang.Override() public  java.lang.Object newPreorderNodeListGenerator() { return null;}
@java.lang.Override() public  java.lang.Object newCollectRequest() { return null;}
@java.lang.Override() public  java.lang.Object newDependency(java.lang.Object defaultArtifact, java.lang.String scope) { return null;}
@java.lang.Override() public  java.lang.Object newDefaultArtifact(java.lang.Object artifact) { return null;}
@java.lang.Override() public  java.lang.Object newArtifactRequest() { return null;}
@java.lang.Override() public  java.lang.Object newSubArtifact(java.lang.Object artifact, java.lang.String classifier, java.lang.String extension) { return null;}
@java.lang.Override() public  java.lang.Object newPatternExclusionsDependencyFilter(java.util.List<java.lang.String> excludes) { return null;}
@java.lang.Override() public  java.lang.Object newDependencyFilter(java.lang.Object filterClosure) { return null;}
@java.lang.Override() public  org.reficio.p2.resolver.maven.Artifact translateArtifactAetherToGeneric(java.lang.Object artifact) { return (org.reficio.p2.resolver.maven.Artifact)null;}
@java.lang.Override() public  java.lang.Object translateArtifactGenericToAether(org.reficio.p2.resolver.maven.Artifact a) { return null;}
}
